@@ -266,20 +266,26 @@ class Loaf:
         if values == "" or values == []:
             raise Exception("No VALUES specified.")
         # First fabricate the query string.
-        if type(into) == list:
-            if type(values) == list:
-                if len(into) != len(values):
-                    raise Exception("The INTO and VALUES must be the same amount.")
-                into = ", ".join(into)
-                values = ", ".join(values)
-            else:
-                into = ", ".join(into)
+        if type(into) != type(values):
+            raise Exception("The INTO and VALUES arguments must be of the same type.")
+        if type(into) == str:
+            finalInto = parse(into)
+            finalValues = parse(values)
+        elif type(into) == list:
+            if len(into) != len(values):
+                raise Exception("The INTO and VALUES arguments must be the same length.")
+            finalInto = ""
+            finalValues = ""
+            for i in range(len(into)):
+                finalInto += into[i] + ", "
+                finalValues += parse(values[i]) + ", "
+            finalInto = finalInto[:-2]
+            finalValues = finalValues[:-2]
         else:
-            if type(values) == list:
-                values = ", ".join(values)
+            raise Exception("Invalid INTO or VALUES type.")
         # Execute the query.
         try:
-            self.cursor.execute(f"INSERT INTO {table} ({into}) VALUES ({values})")
+            self.cursor.execute(f"INSERT INTO {table} ({finalInto}) VALUES ({finalValues})")
         except Exception as e:
             if rollback_on_error:
                 self.conn.rollback()
